const NotificationProvider = require("./notification-provider");
const axios = require("axios");
const { DOWN, UP } = require("../../src/util");

class PushPlus extends NotificationProvider {
    name = "PushPlus";

    /**
     * @inheritdoc
     */

    async send(notification, msg, monitorJSON = null, heartbeatJSON = null) {
        const okMsg = "Sent Successfully.";
        const url = `https://www.pushplus.plus/send`;
        try {
            await axios.post(url, {
                "token": notification.pushPlusSendToken,
                "title": this.checkStatus(heartbeatJSON, monitorJSON),
                "content": msg,
                "template": "html"
            }, { headers: { "Content-Type": "application/json" } }
        );
            return okMsg;

        } catch (error) {
            this.throwGeneralAxiosError(error);
            console.error("PushPlus Error:", error.response?.data || error.message);
            throw new Error("Notification failed: " + error.message);
        }
    }

    /**
     * Get the formatted title for message
     * @param {?object} heartbeatJSON Heartbeat details (For Up/Down only)
     * @param {?object} monitorJSON Monitor details (For Up/Down only)
     * @returns {string} Formatted title
     */
    checkStatus(heartbeatJSON, monitorJSON) {
        let title = "UptimeKuma Message";
        if (heartbeatJSON != null && heartbeatJSON["status"] === UP) {
            title = "UptimeKuma Monitor Up " + monitorJSON["name"];
        }
        if (heartbeatJSON != null && heartbeatJSON["status"] === DOWN) {
            title = "UptimeKuma Monitor Down " + monitorJSON["name"];
        }
        return title;
    }
}

module.exports = PushPlus;